BOOST_PP_OVERLOAD

The BOOST_PP_OVERLOAD variadic macro expands to the name of a non-variadic macro having a given number of parameters.

#### Usage

BOOST_PP_OVERLOAD(prefix,...) (v)

#### Arguments

prefix
  The prefix of the non-variadic macro name.
...
  Variadic data. The number of variadic data elements, as determined by BOOST_PP_VARIADIC_SIZE, is appended to the prefix to form the output non-variadic macro name.

#### Remarks

This macro creates a macro name which depends on the number of elements of variadic data. It should be used in the form of
BOOST_PP_OVERLOAD(MACRO_NAME_,__VA_ARGS__)(__VA_ARGS__) in order to call a non-variadic macro taking a given number of variadic data elements as non-variadic arguments. In this way one can invoke a variadic macro with a variable number of parameters which calls one of a series of non-variadic macros doing very similar things.
Requirements
Header: <boost/preprocessor/facilities/overload.hpp>

#### Sample Code

    #include <boost/preprocessor/facilities/overload.hpp>
    #include <boost/preprocessor/cat.hpp>
    #include <boost/preprocessor/facilities/empty.hpp>
    #include <boost/preprocessor/arithmetic/add.hpp>

    #define MACRO_1(number) MACRO_2(number,10)
    #define MACRO_2(number1,number2) BOOST_PP_ADD(number1,number2)

    #if !BOOST_PP_VARIADICS_MSVC

    #define MACRO_ADD_NUMBERS(...) BOOST_PP_OVERLOAD(MACRO_,__VA_ARGS__)(__VA_ARGS__)

    #else

    // or for Visual C++

    #define MACRO_ADD_NUMBERS(...) \
      BOOST_PP_CAT(BOOST_PP_OVERLOAD(MACRO_,__VA_ARGS__)(__VA_ARGS__),BOOST_PP_EMPTY())

    #endif

    MACRO_ADD_NUMBERS(5) // output is 15
    MACRO_ADD_NUMBERS(3,6) // output is 9

© Copyright Edward Diener 2011,2013,2016

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)